@@ -32,15 +32,16 @@ enum class KeyState : uint32_t {
     Ctrl_Alt_Shift = Ctrl | Alt | Shift,
     NumLock = 1 << 4,
     Mod2 = NumLock,
-    Mod3 = 1 << 5,
+    Hyper = 1 << 5,
+    Mod3 = Hyper,
     Super = 1 << 6,
     Mod4 = Super,
     Mod5 = 1 << 7,
     MousePressed = 1 << 8,
     HandledMask = 1 << 24,
     IgnoredMask = 1 << 25,
-    Super2 = 1 << 26,
-    Hyper = 1 << 27,
+    Super2 = 1 << 26, // Gtk virtual Super
+    Hyper2 = 1 << 27, // Gtk virtual Hyper
     Meta = 1 << 28,
     UsedMask = 0x5c001fff,
     SimpleMask = Ctrl_Alt_Shift | Super | Super2 | Hyper | Meta,
